use actix_identity::Identity;
use actix_web::{http::header::LOCATION, web, HttpResponse, Responder};
use askama::Template;
use sqlx::PgPool;

use crate::models::{role::Role, user::User};

pub fn init(cfg: &mut web::ServiceConfig) {
    cfg.service(get_index);
}

#[derive(Template)]
#[template(path = "index.html")]
struct CalendarTemplate {
    user_role: Role,
}

#[actix_web::get("/")]
async fn get_index(user: Option<Identity>, pool: web::Data<PgPool>) -> impl Responder {
    if let Some(user) = user {
        let current_user = User::read_by_id(pool.get_ref(), user.id().unwrap().parse().unwrap()).await.unwrap();

        let template = CalendarTemplate{ user_role: current_user.role };

        HttpResponse::Ok().body(template.render().unwrap())
    } else {
        HttpResponse::PermanentRedirect()
            .insert_header((LOCATION, "/login"))
            .finish()
    }
}
